﻿using Connected.Models;
using Microsoft.AspNetCore.Components;

namespace Connected.Components;
public partial class TextInput : InputBase
{

	[Parameter]
	public bool IsPassword { get; set; } = false;

	[Parameter]
	public int NumOfRows
	{
		get
		{
			return _numberOfLines;
		}
		set
		{
			_numberOfLines = Math.Max(1, value);
		}
	}
	private int _numberOfLines = 1;


	[Parameter]
	public string Value { get; set; } = string.Empty;

	private string InputType => IsPassword ? "password" : "text";

	[Parameter]
	public EventCallback<string> ValueChanged { get; set; }

	private async Task ChangeValueAsync(ChangeEventArgs args)
	{
		await ValueChanged.InvokeAsync(args?.Value?.ToString());
	}

	private async Task Clear()
	{
		await ValueChanged.InvokeAsync(string.Empty);
	}

	protected override async Task OnInitializedAsync()
	{
		await base.OnInitializedAsync();

		if (Required && !InputAttributes.ContainsKey("required"))
			InputAttributes.Add("required", true);
	}
}